# BOLD Quality Control (beta)
BOLDQC is an automated quality control pipeline for functional MRI scans. BOLDQC
is built on top of the excellent
[`dcm2niix`](https://github.com/rordenlab/dcm2niix), 
[`FreeSurfer`](https://surfer.nmr.mgh.harvard.edu/),
and
[`FSL`](https://fsl.fmrib.ox.ac.uk/fsl)
software packages.

For the latest documentation please head over to [boldqc.readthedocs.io](https://boldqc.readthedocs.io).

